import argparse
import os
from FastWrite import file_processor, doc_generator

def main():
    parser = argparse.ArgumentParser(description="Generate documentation for a Python file using FastWrite.")
    parser.add_argument("filename", help="Python source file to document.")
    parser.add_argument("--LLM_NAME", required=True, help="Name of the LLM to use for documentation (for reference).")
    args = parser.parse_args()

    if not os.path.isfile(args.filename):
        print(f"Error: File '{args.filename}' does not exist.")
        return

    print(f"Processing file: {args.filename} using LLM: {args.LLM_NAME}")

    # Read the file contents
    with open(args.filename, 'r') as f:
        code = f.read()

    # Process the code into chunks
    chunks = file_processor.chunk_code(code)

    # Generate documentation
    documentation = doc_generator.generate_documentation(chunks)

    # Write the output to README.md
    with open("README.md", "w") as readme_file:
        readme_file.write(f"# Documentation generated by FastWrite using {args.LLM_NAME}\n\n")
        readme_file.write(documentation)

    print("Documentation has been written to README.md")

if __name__ == "__main__":
    main()
